==> studio-6.5.4.zip: studio-6.5.4/templates/plugin/to_process/component/src/main/java/${componentPackageSlashes}/${componentClassName}.java <==
package ${componentPackage};

import com.haulmont.studio.common.model.InheritanceState;
import com.haulmont.studio.ui.sd.layout.ModelHelper;
import com.haulmont.studio.ui.sd.layout.gui.*;
import com.haulmont.studio.ui.sd.layout.gui.VaadinComponent;
import com.haulmont.studio.ui.sd.layout.layouts.EditableVerticalLayout;
import com.vaadin.ui.HorizontalLayout;
import fi.jasoft.dragdroplayouts.client.ui.LayoutDragMode;
import com.vaadin.ui.Alignment;
import com.haulmont.studio.ui.sd.layout.components.InternalLabel;
<%if (customProperties) {%>import com.haulmont.studio.ui.sd.layout.model.baseprop.*;<%}%>

import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

@VaadinComponent(HorizontalLayout.class)
@DisplayName("${componentName}")
public class ${componentClassName} extends EditableVerticalLayout implements GuiComponent, BlackBox<%if (standardProperties.contains("editable")) {%>, GuiComponent.Editable<%}%><%if (standardProperties.contains("icon")) {%>, GuiComponent.HasIcon<%}%><%if (standardProperties.contains("caption")) {%>, GuiComponent.HasCaption<%}%><%if (standardProperties.contains("datasource")) {%>, DataAware<%}%><%if (standardProperties.contains("property")) {%>, AttributeDataAware<%}%> {

    private String id;
    private InheritanceState inheritanceState;
    private Map<String, InheritanceState> inheritanceMap = new HashMap<>();
    private UUID internalId;
    private boolean componentEnabled = true;
    private boolean componentVisible = true;
    private String componentStyleName;
    <%if (standardProperties.contains("editable")) {%>
    private boolean editable = true;<%}%><%if (standardProperties.contains("icon")) {%>
    private String icon;<%}%><%if (standardProperties.contains("caption")) {%>
    private String componentCaption;<%}%><%if (standardProperties.contains("datasource")) {%>
    private String datasource;<%}%><%if (standardProperties.contains("property")) {%>
    private String property;<%}%>
    <%customProperties.each{property->%>private ${property.propertyType} ${property.name}<%if (property.defaultValue != null) {%> = ${property.formattedDefaultValue}<%}%>;
    <%}%>

    public ${componentClassName}() {
        setDragMode(LayoutDragMode.NONE);
        setDropHandler(null);
        setMargin(true);
        InternalLabel label = new InternalLabel("${componentName}");
        addComponent(label);
        setComponentAlignment(label, Alignment.MIDDLE_CENTER);
    }

    @Override
    public String getComponentStyleName() {
        return componentStyleName;
    }

    @Override
    public void setComponentStyleName(String name) {
        this.componentStyleName = name;
    }

    @Override
    public String getComponentId() {
        return id;
    }

    @Override
    public void setComponentId(String id) {
        this.id = id;
    }

    @Override
    public UUID getInternalId() {
        return internalId;
    }

    @Override
    public void setInternalId(UUID internalId) {
        this.internalId = internalId;
    }

    @Override
    public boolean isComponentEnabled() {
        return componentEnabled;
    }

    @Override
    public void setComponentEnabled(boolean componentEnabled) {
        this.componentEnabled = componentEnabled;
        setEnabled(componentEnabled);
    }

    @Override
    public boolean isComponentVisible() {
        return componentVisible;
    }

    @Override
    public void setComponentVisible(boolean componentVisible) {
        this.componentVisible = componentVisible;
        setVisible(componentVisible);
    }

    @Override
    public InheritanceState getInheritanceState() {
        return inheritanceState;
    }

    @Override
    public void setInheritanceState(InheritanceState inheritanceState) {
        this.inheritanceState = inheritanceState;
    }

    @Override
    public Map<String, InheritanceState> getInheritanceMap() {
        return inheritanceMap;
    }

    @Override
    public void setInheritanceMap(Map<String, InheritanceState> inheritanceMap) {
        this.inheritanceMap = inheritanceMap;
    }<%if (standardProperties.contains("editable")) {%>

    @Override
    public boolean isEditable() {
        return editable;
    }

    @Override
    public void setEditable(boolean editable) {
        this.editable = editable;
    }<%}%><%if (standardProperties.contains("icon")) {%>

    @Override
    public String getIconString() {
        return icon;
    }

    @Override
    public void setIconString(String icon) {
        this.icon = icon;
    }<%}%><%if (standardProperties.contains("caption")) {%>

    @Override
    public String getComponentCaption() {
        return componentCaption;
    }

    @Override
    public void setComponentCaption(String componentCaption) {
        this.componentCaption = componentCaption;
        setCaption(ModelHelper.shortCaption(componentCaption));
    }<%}%><%if (standardProperties.contains("datasource")) {%>

    @Override
    public String getDatasource() {
        return datasource;
    }

    @Override
    public void setDatasource(String datasource) {
        this.datasource = datasource;
    }<%}%><%if (standardProperties.contains("property")) {%>

    @Override
    public String getProperty() {
        return property;
    }

    @Override
    public void setProperty(String property) {
        this.property = property;
    }<%}%>
<%customProperties.each{property->%>
    public ${property.propertyType} ${property.propertyType == 'boolean' ? 'is' : 'get'}${property.nameUpperCase}() {
        return ${property.name};
    }

    public void set${property.nameUpperCase}(${property.propertyType} ${property.name}) {
        this.${property.name} = ${property.name};
    }
<%}%>
}

==> studio-6.9.2.zip: studio-6.9.2/templates/plugin/to_process/component/src/main/java/${componentPackageSlashes}/${componentClassName}.java <==
package ${componentPackage};

import com.haulmont.studio.common.model.InheritanceState;
import com.haulmont.studio.ui.sd.layout.ModelHelper;
import com.haulmont.studio.ui.sd.layout.gui.*;
import com.haulmont.studio.ui.sd.layout.gui.VaadinComponent;
import com.haulmont.studio.ui.sd.layout.layouts.EditableVerticalLayout;
import com.vaadin.ui.HorizontalLayout;
import fi.jasoft.dragdroplayouts.client.ui.LayoutDragMode;
import com.vaadin.ui.Alignment;
import com.haulmont.studio.ui.sd.layout.components.InternalLabel;
<%if (customProperties) {%>import com.haulmont.studio.ui.sd.layout.model.baseprop.*;<%}%>

import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

@VaadinComponent(HorizontalLayout.class)
@DisplayName("${componentName}")
public class ${componentClassName} extends EditableVerticalLayout implements GuiComponent, BlackBox<%if (standardProperties.contains("editable")) {%>, GuiComponent.Editable<%}%><%if (standardProperties.contains("icon")) {%>, GuiComponent.HasIcon<%}%><%if (standardProperties.contains("caption")) {%>, GuiComponent.HasCaption<%}%><%if (standardProperties.contains("datasource")) {%>, DataAware<%}%><%if (standardProperties.contains("property")) {%>, AttributeDataAware<%}%> {

    private String id;
    private InheritanceState inheritanceState;
    private Map<String, InheritanceState> inheritanceMap = new HashMap<>();
    private UUID internalId;
    private boolean componentEnabled = true;
    private boolean componentVisible = true;
    private String componentStyleName;
    <%if (standardProperties.contains("editable")) {%>
    private boolean editable = true;<%}%><%if (standardProperties.contains("icon")) {%>
    private String icon;<%}%><%if (standardProperties.contains("caption")) {%>
    private String componentCaption;<%}%><%if (standardProperties.contains("datasource")) {%>
    private String datasource;<%}%><%if (standardProperties.contains("property")) {%>
    private String property;<%}%>
    <%customProperties.each{property->%>private ${property.propertyType} ${property.name}<%if (property.defaultValue != null) {%> = ${property.formattedDefaultValue}<%}%>;
    <%}%>

    public ${componentClassName}() {
        setDragMode(LayoutDragMode.NONE);
        setDropHandler(null);
        setMargin(true);
        InternalLabel label = new InternalLabel("${componentName}");
        addComponent(label);
        setComponentAlignment(label, Alignment.MIDDLE_CENTER);
    }

    @Override
    public String getComponentStyleName() {
        return componentStyleName;
    }

    @Override
    public void setComponentStyleName(String name) {
        this.componentStyleName = name;
    }

    @Override
    public String getComponentId() {
        return id;
    }

    @Override
    public void setComponentId(String id) {
        this.id = id;
    }

    @Override
    public UUID getInternalId() {
        return internalId;
    }

    @Override
    public void setInternalId(UUID internalId) {
        this.internalId = internalId;
    }

    @Override
    public boolean isComponentEnabled() {
        return componentEnabled;
    }

    @Override
    public void setComponentEnabled(boolean componentEnabled) {
        this.componentEnabled = componentEnabled;
        setEnabled(componentEnabled);
    }

    @Override
    public boolean isComponentVisible() {
        return componentVisible;
    }

    @Override
    public void setComponentVisible(boolean componentVisible) {
        this.componentVisible = componentVisible;
        setVisible(componentVisible);
    }

    @Override
    public InheritanceState getInheritanceState() {
        return inheritanceState;
    }

    @Override
    public void setInheritanceState(InheritanceState inheritanceState) {
        this.inheritanceState = inheritanceState;
    }

    @Override
    public Map<String, InheritanceState> getInheritanceMap() {
        return inheritanceMap;
    }

    @Override
    public void setInheritanceMap(Map<String, InheritanceState> inheritanceMap) {
        this.inheritanceMap = inheritanceMap;
    }<%if (standardProperties.contains("editable")) {%>

    @Override
    public boolean isEditable() {
        return editable;
    }

    @Override
    public void setEditable(boolean editable) {
        this.editable = editable;
    }<%}%><%if (standardProperties.contains("icon")) {%>

    @Override
    public String getIconString() {
        return icon;
    }

    @Override
    public void setIconString(String icon) {
        this.icon = icon;
    }<%}%><%if (standardProperties.contains("caption")) {%>

    @Override
    public String getComponentCaption() {
        return componentCaption;
    }

    @Override
    public void setComponentCaption(String componentCaption) {
        this.componentCaption = componentCaption;
        setCaption(ModelHelper.captionLocalized(componentCaption, getData()));
    }<%}%><%if (standardProperties.contains("datasource")) {%>

    @Override
    public String getDatasource() {
        return datasource;
    }

    @Override
    public void setDatasource(String datasource) {
        this.datasource = datasource;
    }<%}%><%if (standardProperties.contains("property")) {%>

    @Override
    public String getProperty() {
        return property;
    }

    @Override
    public void setProperty(String property) {
        this.property = property;
    }<%}%>
<%customProperties.each{property->%>
    public ${property.propertyType} ${property.propertyType == 'boolean' ? 'is' : 'get'}${property.nameUpperCase}() {
        return ${property.name};
    }

    public void set${property.nameUpperCase}(${property.propertyType} ${property.name}) {
        this.${property.name} = ${property.name};
    }
<%}%>
}
